@@ -107,7 +107,7 @@ static void
 string_extents (gchar *string, Extents *ext)
 {
     gkrellm_text_extents(ext->ts.font, string, strlen(string),
-			&ext->width, &ext->height, &ext->baseline, &ext->y_ink);
+                        &ext->width, &ext->height, &ext->baseline, &ext->y_ink);
 }
 
 /* reference from wmWeather.c */
@@ -129,8 +129,8 @@ read_air ()
         if (air.name[0] == '\0' || air.name[0] == '\n')
         {   /* GrabWeather could not read data from server */
             fclose(fp);
-	    setlocale(LC_NUMERIC, oldlocale);
-	    g_free(oldlocale);
+            setlocale(LC_NUMERIC, oldlocale);
+            g_free(oldlocale);
             return FALSE;
         }
         for (c = air.name; *c && *c != '('; c++); /* extract name */
@@ -150,9 +150,9 @@ read_air ()
         else {
             air.sky_cond_avail = 1;
         }
-	if (air.sky_cond[strlen(air.sky_cond)-1] == '\n') 
-	    air.sky_cond[strlen(air.sky_cond)-1] = '\0';
-	
+        if (air.sky_cond[strlen(air.sky_cond)-1] == '\n') 
+            air.sky_cond[strlen(air.sky_cond)-1] = '\0';
+        
 
         fgets(line, 512, fp);
 
@@ -197,8 +197,9 @@ read_air ()
     // Change tooltips
     if (weather_tips != NULL)
     {
-        sprintf(line, "%s/.wmWeatherReports/%s.TXT", getenv("HOME"),
+        snprintf(line, 512, "%s/.wmWeatherReports/%s.TXT", getenv("HOME"),
                 options.station);
+        options.station[511] = 0;
         if ((fp = fopen(line, "r")) != NULL) {
             g_free(weather_tips_text);
             cursize = 0;
@@ -281,21 +282,21 @@ draw_panel ()
     switch (panel_state) {
         case NAM_DISPLAY:
             w = gkrellm_chart_width();
-	    if (x_scroll > name_xoff)
-		x_scroll -= 2;
-	    else
-		x_scroll = w;
+            if (x_scroll > name_xoff)
+                x_scroll -= 2;
+            else
+                x_scroll = w;
             decal_name->x_off = x_scroll;
             gkrellm_draw_decal_text(panel, decal_name, air.name, w - x_scroll);
             break;
         case SKY_DISPLAY:
             if (air.sky_cond_avail) {
                 w = gkrellm_chart_width();
-		if (x_scroll > sky_cond_xoff)
-		    x_scroll -= 2;
-		else
-		    x_scroll = w;
-		decal_sky_cond->x_off = x_scroll;
+                if (x_scroll > sky_cond_xoff)
+                    x_scroll -= 2;
+                else
+                    x_scroll = w;
+                decal_sky_cond->x_off = x_scroll;
                 gkrellm_draw_decal_text(panel, decal_sky_cond, air.sky_cond,
                         w - x_scroll);
             }
@@ -307,22 +308,26 @@ draw_panel ()
             if (options.metric && options.windspeed_unit == 3)
             {
                 v = lrintf(air.wind_speed[3]);
-                sprintf(l2, "F%d", v);
+                snprintf(l2, 8, "F%d", v);
+                l2[7] = 0;
                 v += 1000;   /* to distinguish redraws */
             }
             else
             {
                 v = lrintf(air.wind_speed[options.metric ? options.windspeed_unit : 0]);
-                sprintf(l2, "%.0d", v);
+                snprintf(l2, 8, "%.0d", v);
+                l2[7] = 0;
             }
             gkrellm_draw_decal_text(panel, decal_wind_speed, l2, v);
             break;
         case DEW_DISPLAY:
             v = lrintf(air.dew_point[options.metric]);
-            sprintf(l1, "%+4d", v);
+            snprintf(l1, 8, "%+4d", v);
+            l1[7] = 0;
             gkrellm_draw_decal_text(panel, decal_dew_point, l1, v);
             v = lrintf(air.pressure[options.metric ? options.pressure_unit : 0]);
-            sprintf(l2, "%4d", v);
+            snprintf(l2, 7, "%4d", v);
+            l2[7] = 0;
             gkrellm_draw_decal_text(panel, decal_pressure, l2, v);
             units = options.metric ? "C" : "F";
             gkrellm_draw_decal_text(panel, decal_unit1, units, options.metric);
@@ -330,10 +335,12 @@ draw_panel ()
         case TEM_DISPLAY:
         default:
             v = lrintf(air.temperature[options.metric]);
-            sprintf(l1, "%+4d", v);
+            snprintf(l1, 8, "%+4d", v);
+            l1[7] = 0;
             gkrellm_draw_decal_text(panel, decal_temperature, l1, v);
             v = lrintf(air.humidity);
-            sprintf(l2, "%3d", v);
+            snprintf(l2, 8, "%3d", v);
+            l2[7] = 0;
             gkrellm_draw_decal_text(panel, decal_humidity, l2, v);
             units = options.metric ? "C" : "F";
             gkrellm_draw_decal_text(panel, decal_unit1, units, options.metric);
@@ -714,11 +721,13 @@ apply_air_config (void)
         options.station[1] = c[1];
         options.station[2] = c[2];
         options.station[3] = c[3];
-        sprintf(options.command, PREFIX "/bin/GrabWeather %s", options.station);
-        sprintf(options.filename, "%s/.wmWeatherReports/%s.dat",
+        snprintf(options.command, 512, PREFIX "/bin/GrabWeather %s", options.station);
+        options.command[511] = 0;
+        snprintf(options.filename, 512, "%s/.wmWeatherReports/%s.dat",
                 getenv("HOME"), options.station);
-	net_update = FALSE;
-	run_command();
+        options.filename[511] = 0;
+        net_update = FALSE;
+        run_command();
     }
     g_free(c);
     options.update_interval = gtk_spin_button_get_value_as_int(
@@ -977,9 +986,11 @@ read_default(void)
     options.windspeed_unit = 1;
     options.pressure_unit = 1;
     strcpy(options.station, DEFAULT_STATION_ID);
-    sprintf(options.command, "/usr/share/gkrellm/GrabWeather %s", options.station);
-    sprintf(options.filename, "%s/.wmWeatherReports/%s.dat",
-            getenv("HOME"), options.station);
+    snprintf(options.command, 512, "/usr/share/gkrellm/GrabWeather %s", options.station);
+    options.command[511] = 0;
+    snprintf(options.filename, 512, "%s/.wmWeatherReports/%s.dat",
+             getenv("HOME"), options.station);
+    options.filename[511] = 0;
 }
 
 
